SteelScript AppResponse
=======================

.. currentmodule:: steelscript.appresponse.core.appresponse


Welcome to the documentation for the SteelScript SDK for SteelCentral
AppResponse.

As in our other product-oriented SDKs, our primary interface to an
AppResponse appliance will be through the class :py:class:`AppResponse`.
This object can be instantiated with a hostname and some authentication
parameters, and then used as the object for all follow-on operations.

Detailed documentation may be found on the following pages:

* Report Tutorial

  * :doc:`tutorial`

* Example Scripts

  * :doc:`examples`

* Reporting and Configuration

  * :doc:`appresponse`

* Changelog and Upgrades
  
  * :doc:`changelog`
